@@ -9,11 +9,7 @@ import discretize
 from scipy.spatial import cKDTree, Delaunay
 from scipy import interpolate
 
-import sys
-if sys.version_info < (3,):
-    num_types = [int, long, float]
-else:
-    num_types = [int, float]
+num_types = [int, float]
 
 
 def exampleLrmGrid(nC, exType):
@@ -89,11 +85,11 @@ def random_model(shape, seed=None, anisotropy=None, its=100, bounds=None):
     np.random.seed(seed)
     mr = np.random.rand(*shape)
     if anisotropy is None:
-        if len(shape) is 1:
+        if len(shape) == 1:
             smth = np.array([1, 10., 1], dtype=float)
-        elif len(shape) is 2:
+        elif len(shape) == 2:
             smth = np.array([[1, 7, 1], [2, 10, 2], [1, 7, 1]], dtype=float)
-        elif len(shape) is 3:
+        elif len(shape) == 3:
             kernal = np.array([1, 4, 1], dtype=float).reshape((1, 3))
             smth = np.array(sp.kron(sp.kron(kernal, kernal.T).todense()[:], kernal).todense()).reshape((3, 3, 3))
     else:
